==> func_bk-1.5.7.tar.gz: func_bk-1.5.7/func_bk/fast_api.py <==
from fastapi import FastAPI, Response
from fastapi.responses import JSONResponse
from fastapi.utils import generate_unique_id
from typing import Any, List, Union
from enum import Enum


def path(
        app: FastAPI,
        func: callable,
        type: str,
        path: str,
        response_model: Any = None,
        status_code: int = None,
        tags: List[Union[str, Enum]] = None,
        dependencies = None,
        summary: str = None,
        description: str = None,
        response_description: str = "Successful Response",
        responses = None,
        deprecated: bool = None,
        operation_id = None,
        response_model_include = None,
        response_model_exclude = None,
        response_model_by_alias: bool = True,
        response_model_exclude_unset: bool = False,
        response_model_exclude_defaults: bool = False,
        response_model_exclude_none: bool = False,
        include_in_schema: bool = True,
        response_class: type[Response] = JSONResponse,
        name: str = None,
        callbacks = None,
        openapi_extra = None,
        generate_unique_id_function = generate_unique_id
    ):
    type = type.lower()
    route_function = None
    if type == "get":
        route_function = app.get
    elif type == "post":
        route_function = app.post
    elif type == "put":
        route_function = app.put
    elif type == "delete":
        route_function = app.delete
    elif type == "patch":
        route_function = app.patch

    if route_function:
        route_function(
            path=path,
            response_model=response_model,
            status_code=status_code,
            tags=tags,
            dependencies=dependencies,
            summary=summary,
            description=description,
            response_description=response_description,
            responses=responses,
            deprecated=deprecated,
            operation_id=operation_id,
            response_model_include=response_model_include,
            response_model_exclude=response_model_exclude,
            response_model_by_alias=response_model_by_alias,
            response_model_exclude_unset=response_model_exclude_unset,
            response_model_exclude_defaults=response_model_exclude_defaults,
            response_model_exclude_none=response_model_exclude_none,
            include_in_schema=include_in_schema,
            response_class=response_class,
            name=name,
            callbacks=callbacks,
            openapi_extra=openapi_extra,
            generate_unique_id_function=generate_unique_id_function
        )(func)

class Label():
    type: str
    id: str
    placeholder: str
    help_text: str
    style_input:str
    def __init__(self,atype:str,aid:str,place:str = None,help:str = None,style:str = None):
        self.type=atype
        self.id=aid
        self.placeholder=place
        self.help_text=help
        self.style_input=style


class BForm():
    def labels(self):
        a=[]
        cls=type(self)
        for i in cls.__dict__.items():
            if isinstance(i, Label):
                a.append(i)   
        return a

    def as_p(self):
        a=''
        all=self.labels()

        for i in all:
            if not(i.style_input):
                a += f"<input type='{i.type}' id='{i.id}' name='{i.id}' placeholder='{i.placeholder}'> \n"
            else:
                a += f"<input class='{i.style_input}' type='{i.type}' id='{i.id}' name='{i.id}' placeholder='{i.placeholder}'> \n"

            a += f"<p>{i.help_text}</p> \n"

        return a

==> func_bk-1.5.9.tar.gz: func_bk-1.5.9/func_bk/fast_api.py <==
from fastapi import FastAPI, Response
from fastapi.responses import JSONResponse
from fastapi.utils import generate_unique_id
from typing import Any, List, Union
from enum import Enum

from markupsafe import Markup


def path(
        app: FastAPI,
        func: callable,
        type: str,
        path: str,
        response_model: Any = None,
        status_code: int = None,
        tags: List[Union[str, Enum]] = None,
        dependencies = None,
        summary: str = None,
        description: str = None,
        response_description: str = "Successful Response",
        responses = None,
        deprecated: bool = None,
        operation_id = None,
        response_model_include = None,
        response_model_exclude = None,
        response_model_by_alias: bool = True,
        response_model_exclude_unset: bool = False,
        response_model_exclude_defaults: bool = False,
        response_model_exclude_none: bool = False,
        include_in_schema: bool = True,
        response_class: type[Response] = JSONResponse,
        name: str = None,
        callbacks = None,
        openapi_extra = None,
        generate_unique_id_function = generate_unique_id
    ):
    type = type.lower()
    route_function = None
    if type == "get":
        route_function = app.get
    elif type == "post":
        route_function = app.post
    elif type == "put":
        route_function = app.put
    elif type == "delete":
        route_function = app.delete
    elif type == "patch":
        route_function = app.patch

    if route_function:
        route_function(
            path=path,
            response_model=response_model,
            status_code=status_code,
            tags=tags,
            dependencies=dependencies,
            summary=summary,
            description=description,
            response_description=response_description,
            responses=responses,
            deprecated=deprecated,
            operation_id=operation_id,
            response_model_include=response_model_include,
            response_model_exclude=response_model_exclude,
            response_model_by_alias=response_model_by_alias,
            response_model_exclude_unset=response_model_exclude_unset,
            response_model_exclude_defaults=response_model_exclude_defaults,
            response_model_exclude_none=response_model_exclude_none,
            include_in_schema=include_in_schema,
            response_class=response_class,
            name=name,
            callbacks=callbacks,
            openapi_extra=openapi_extra,
            generate_unique_id_function=generate_unique_id_function
        )(func)

class Label():
    type: str
    id: str
    placeholder: str
    help_text: str
    style_input:str
    def __init__(self,atype:str,aid:str,place:str = "",help:str = "",style:str = None):
        self.type=atype
        self.id=aid
        self.placeholder=place
        self.help_text=help
        self.style_input=style


class BForm():
    def labels(self):
        a=[]
        cls=type(self)
        for i in cls.__dict__:
            if isinstance(cls.__dict__[i], Label):
                a.append(cls.__dict__[i])   
        return a

    def as_p(self):
        a=''
        all=self.labels()

        for i in all:
            if not(i.style_input):
                a += f"<input type='{i.type}' id='{i.id}' name='{i.id}' placeholder='{i.placeholder}'> \n"
            else:
                a += f"<input class='{i.style_input}' type='{i.type}' id='{i.id}' name='{i.id}' placeholder='{i.placeholder}'> \n"

            a += f"<p>{i.help_text}</p> \n"

        return Markup(a)
